summaryrefslogtreecommitdiffstats
path: root/meta-phosphor/recipes-phosphor/interfaces/bmcweb/0001-Increase-request-limit.patch
blob: ce710cbfd75f47905d3379d4384501c6fb025ccf (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
diff --git a/crow/include/crow/http_connection.h b/crow/include/crow/http_connection.h
index 6f44186..6c23b63 100644
--- a/crow/include/crow/http_connection.h
+++ b/crow/include/crow/http_connection.h
@@ -241,8 +241,8 @@ typename std::enable_if<(N > 0)>::type
 static std::atomic<int> connectionCount;
 #endif
 
-// request body limit size: 30M
-constexpr unsigned int httpReqBodyLimit = 1024 * 1024 * 30;
+// request body limit size: 128M
+constexpr unsigned int httpReqBodyLimit = 1024 * 1024 * 128;
 
 template <typename Adaptor, typename Handler, typename... Middlewares>
 class Connection
OpenPOWER on IntegriCloud